@@ -104,8 +104,8 @@ class DiffusionAnalyzer(PMGSONable):
     """
 
     def __init__(self, structure, displacements, specie, temperature,
-                 time_step, step_skip, smoothed=True, min_obs=30,
-                 weighted=True):
+                 time_step, step_skip, smoothed="max", min_obs=30,
+                 avg_nsteps=1000):
         """
         This constructor is meant to be used with pre-processed data.
         Other convenient constructors are provided as class methods (see
@@ -133,19 +133,27 @@ class DiffusionAnalyzer(PMGSONable):
             step_skip (int): Sampling frequency of the displacements (
                 time_step is multiplied by this number to get the real time
                 between measurements)
-            smoothed (bool): Whether to smooth the MSD. Generally more
-                accurate, but makes error analysis complicated.
-            min_obs (int): Minimum number of observations to have before
-                including in the MSD vs dt calculation. E.g. If a structure
-                has 10 diffusing atoms, and min_obs = 30, the MSD vs dt will be
+            smoothed (str): Whether to smooth the MSD, and what mode to smooth.
+                Supported modes are:
+                    i. "max", which tries to use the maximum #
+                       of data points for each time origin, subject to a
+                       minimum # of observations given by min_obs, and then
+                       weights the observations based on the variance
+                       accordingly. This is the default.
+                    ii. "constant", in which each timestep is averaged over
+                        the number of time_steps given by min_steps.
+                    iii. None / False / any other false-like quantity. No
+                       smoothing.
+            min_obs (int): Used with smoothed="max". Minimum number of
+                observations to have before including in the MSD vs dt
+                calculation. E.g. If a structure has 10 diffusing atoms,
+                and min_obs = 30, the MSD vs dt will be
                 calculated up to dt = total_run_time / 3, so that each
                 diffusing atom is measured at least 3 uncorrelated times.
-                Only applies in smoothed=True.
-            weighted (bool): Uses a weighted least squares to fit the
-                MSD vs dt. Weights are proportional to 1/Var, which is
-                in turn proportional to number of *independent* observations.
-                Number of independent (non-overlapping) observations is
-                proportional to 1 / dt. Only applies if smoothed=True.
+                Only applies in smoothed="max".
+            avg_nsteps (int): Used with smoothed="constant". Determines the
+                number of time steps to average over to get the msd for each
+                timestep. Default of 1000 is usually pretty good.
         """
         self.structure = structure
         self.disp = displacements
@@ -154,15 +162,16 @@ class DiffusionAnalyzer(PMGSONable):
         self.time_step = time_step
         self.step_skip = step_skip
         self.min_obs = min_obs
-        self.weighted = weighted
-        self.indices = []
-        self.framework_indices = []
+        self.smoothed = smoothed
+        self.avg_nsteps = avg_nsteps
 
+        indices = []
+        framework_indices = []
         for i, site in enumerate(structure):
             if site.specie.symbol == specie:
-                self.indices.append(i)
+                indices.append(i)
             else:
-                self.framework_indices.append(i)
+                framework_indices.append(i)
         if self.disp.shape[1] < 2:
             self.diffusivity = 0.
             self.conductivity = 0.
@@ -170,7 +179,7 @@ class DiffusionAnalyzer(PMGSONable):
             self.conductivity_components = np.array([0., 0., 0.])
             self.max_framework_displacement = 0
         else:
-            framework_disp = self.disp[self.framework_indices]
+            framework_disp = self.disp[framework_indices]
             drift = np.average(framework_disp, axis=0)[None, :, :]
 
             #drift corrected position
@@ -179,16 +188,20 @@ class DiffusionAnalyzer(PMGSONable):
 
             nions, nsteps, dim = dc.shape
 
-            if smoothed:
+            if not smoothed:
+                timesteps = np.arange(0, nsteps)
+            elif smoothed == "constant":
+                if nsteps <= avg_nsteps:
+                    raise ValueError('Not enough data to calculate diffusivity')
+                timesteps = np.arange(0, nsteps - avg_nsteps)
+            else:
                 #limit the number of sampled timesteps to 200
                 min_dt = int(1000 / (self.step_skip * self.time_step))
-                max_dt = min(len(self.indices) * nsteps // self.min_obs, nsteps)
+                max_dt = min(len(indices) * nsteps // self.min_obs, nsteps)
                 if min_dt >= max_dt:
                     raise ValueError('Not enough data to calculate diffusivity')
                 timesteps = np.arange(min_dt, max_dt,
                                       max(int((max_dt - min_dt) / 200), 1))
-            else:
-                timesteps = np.arange(0, nsteps)
 
             dt = timesteps * self.time_step * self.step_skip
 
@@ -198,39 +211,43 @@ class DiffusionAnalyzer(PMGSONable):
             msd_components = np.zeros(dt.shape + (3,))
 
             lengths = np.array(self.structure.lattice.abc)[None, None, :]
+
             for i, n in enumerate(timesteps):
-                dx = dc[:, n:, :] - dc[:, :-n, :] if smoothed \
-                    else dc[:, i:i+1, :]
+                if not smoothed:
+                    dx = dc[:, i:i + 1, :]
+                    dcomponents = df[:, i:i + 1, :] * lengths
+                elif smoothed == "constant":
+                    dx = dc[:, i:i + avg_nsteps, :] - dc[:, 0:avg_nsteps, :]
+                    dcomponents = (df[:, i:i + avg_nsteps, :]
+                                   - df[:, 0:avg_nsteps, :]) * lengths
+                else:
+                    dx = dc[:, n:, :] - dc[:, :-n, :]
+                    dcomponents = (df[:, n:, :] - df[:, :-n, :]) * lengths
                 sq_disp = dx ** 2
                 sq_disp_ions[:, i] = np.average(np.sum(sq_disp, axis=2), axis=1)
-                msd[i] = np.average(sq_disp_ions[:, i][self.indices])
-                dcomponents = (df[:, n:, :] - df[:, :-n, :] if smoothed
-                               else df[:, i:i+1, :]) * lengths
-                msd_components[i] = \
-                    np.average(dcomponents[self.indices] ** 2, axis=(0, 1))
+                msd[i] = np.average(sq_disp_ions[:, i][indices])
 
-            #run the regression on the msd components
-            if weighted and smoothed:
-                w = 1 / dt
-            else:
-                w = np.ones_like(dt)
+                msd_components[i] = np.average(dcomponents[indices] ** 2,
+                                               axis=(0, 1))
 
-            #weighted least squares
-            def weighted_lstsq(a, b, w):
-                w_root = w ** 0.5
-                return np.linalg.lstsq(a * w_root[:, None], b * w_root)
+            def weighted_lstsq(a, b):
+                if smoothed == "max":
+                    # For max smoothing, we need to weight by variance.
+                    w_root = (1 / dt) ** 0.5
+                    return np.linalg.lstsq(a * w_root[:, None], b * w_root)
+                else:
+                    return np.linalg.lstsq(a, b)
 
             m_components = np.zeros(3)
             m_components_res = np.zeros(3)
             a = np.ones((len(dt), 2))
             a[:, 0] = dt
             for i in range(3):
-                (m, c), res, rank, s = weighted_lstsq(
-                    a, msd_components[:, i], w)
+                (m, c), res, rank, s = weighted_lstsq(a, msd_components[:, i])
                 m_components[i] = max(m, 1e-15)
                 m_components_res[i] = res[0]
 
-            (m, c), res, rank, s = weighted_lstsq(a, msd, w)
+            (m, c), res, rank, s = weighted_lstsq(a, msd)
             #m shouldn't be negative
             m = max(m, 1e-15)
 
@@ -242,10 +259,11 @@ class DiffusionAnalyzer(PMGSONable):
 
             # Calculate the error in the diffusivity using the error in the
             # slope from the lst sq.
-            # Variance in slope = n * Squared Residuals / (n * Sxx - Sx ** 2).
+            # Variance in slope = n * Sum Squared Residuals / (n * Sxx - Sx
+            # ** 2) / (n-2).
             n = len(dt)
             # Pre-compute the denominator since we will use it later.
-            denom = (n * np.sum(dt ** 2) - np.sum(dt) ** 2)
+            denom = (n * np.sum(dt ** 2) - np.sum(dt) ** 2) * (n - 2)
 
             self.diffusivity_std_dev = np.sqrt(n * res[0] / denom) / 60
             self.conductivity = self.diffusivity * conv_factor
@@ -265,12 +283,14 @@ class DiffusionAnalyzer(PMGSONable):
             self.max_ion_displacements = np.max(np.sum(
                 dc ** 2, axis=-1) ** 0.5, axis=1)
             self.max_framework_displacement = \
-                np.max(self.max_ion_displacements[self.framework_indices])
+                np.max(self.max_ion_displacements[framework_indices])
 
             self.msd = msd
             self.sq_disp_ions = sq_disp_ions
             self.msd_components = msd_components
             self.dt = dt
+            self.indices = indices
+            self.framework_indices = framework_indices
 
     def get_drift_corrected_structures(self):
         """
@@ -369,7 +389,9 @@ class DiffusionAnalyzer(PMGSONable):
 
     @classmethod
     def from_structures(cls, structures, specie, temperature,
-                        time_step, step_skip, min_obs=30, weighted=True):
+                        time_step, step_skip, smoothed="max", min_obs=30,
+                        avg_nsteps=1000, initial_disp=None,
+                        initial_structure=None):
         """
         Convenient constructor that takes in a list of Structure objects to
         perform diffusion analysis.
@@ -385,32 +407,62 @@ class DiffusionAnalyzer(PMGSONable):
             step_skip (int): Sampling frequency of the displacements (
                 time_step is multiplied by this number to get the real time
                 between measurements)
-            min_obs (int): Minimum number of observations to have before
-                including in the MSD vs dt calculation. E.g. If a structure
-                has 10 diffusing atoms, and min_obs = 30, the MSD vs dt will be
+            smoothed (str): Whether to smooth the MSD, and what mode to smooth.
+                Supported modes are:
+                    i. "max", which tries to use the maximum #
+                       of data points for each time origin, subject to a
+                       minimum # of observations given by min_obs, and then
+                       weights the observations based on the variance
+                       accordingly. This is the default.
+                    ii. "constant", in which each timestep is averaged over
+                        the same number of observations given by min_obs.
+                    iii. None / False / any other false-like quantity. No
+                       smoothing.
+            min_obs (int): Used with smoothed="max". Minimum number of
+                observations to have before including in the MSD vs dt
+                calculation. E.g. If a structure has 10 diffusing atoms,
+                and min_obs = 30, the MSD vs dt will be
                 calculated up to dt = total_run_time / 3, so that each
                 diffusing atom is measured at least 3 uncorrelated times.
-            weighted (bool): Uses a weighted least squares to fit the
-                MSD vs dt. Weights are proportional to 1/dt, since the
-                number of observations are also proportional to 1/dt (and
-                hence the variance is proportional to dt)
+                Only applies in smoothed="max".
+            avg_nsteps (int): Used with smoothed="constant". Determines the
+                number of time steps to average over to get the msd for each
+                timestep. Default of 1000 is usually pretty good.
+            initial_disp (np.ndarray): Sometimes, you need to iteratively
+                compute estimates of the diffusivity. This supplies an
+                initial displacement that will be added on to the initial
+                displacements. Note that this makes sense only when
+                smoothed=False.
+            initial_structure (Structure): Like initial_disp, this is used
+                for iterative computations of estimates of the diffusivity. You
+                typically need to supply both variables. This stipulates the
+                initial strcture from which the current set of displacements
+                are computed.
         """
         structure = structures[0]
 
         p = [np.array(s.frac_coords)[:, None] for s in structures]
+        if initial_structure is not None:
+            p.insert(0, np.array(initial_structure.frac_coords)[:, None])
+        else:
+            p.insert(0, p[0])
         p = np.concatenate(p, axis=1)
         dp = p[:, 1:] - p[:, :-1]
-        dp = np.concatenate([np.zeros_like(dp[:, (0,)]), dp], axis=1)
         dp = dp - np.round(dp)
         f_disp = np.cumsum(dp, axis=1)
+        if initial_disp is not None:
+            f_disp += structure.lattice.get_fractional_coords(initial_disp)[:,
+                                                              None, :]
         disp = structure.lattice.get_cartesian_coords(f_disp)
 
         return cls(structure, disp, specie, temperature,
-                   time_step, step_skip=step_skip, min_obs=min_obs,
-                   weighted=weighted)
+                   time_step, step_skip=step_skip, smoothed=smoothed,
+                   min_obs=min_obs, avg_nsteps=avg_nsteps)
 
     @classmethod
-    def from_vaspruns(cls, vaspruns, specie, min_obs=30, weighted=True):
+    def from_vaspruns(cls, vaspruns, specie, smoothed="max", min_obs=30,
+                      avg_nsteps=1000, initial_disp=None,
+                      initial_structure=None):
         """
         Convenient constructor that takes in a list of Vasprun objects to
         perform diffusion analysis.
@@ -426,10 +478,37 @@ class DiffusionAnalyzer(PMGSONable):
                 has 10 diffusing atoms, and min_obs = 30, the MSD vs dt will be
                 calculated up to dt = total_run_time / 3, so that each
                 diffusing atom is measured at least 3 uncorrelated times.
-            weighted (bool): Uses a weighted least squares to fit the
-                MSD vs dt. Weights are proportional to 1/dt, since the
-                number of observations are also proportional to 1/dt (and
-                hence the variance is proportional to dt)
+            smoothed (str): Whether to smooth the MSD, and what mode to smooth.
+                Supported modes are:
+                    i. "max", which tries to use the maximum #
+                       of data points for each time origin, subject to a
+                       minimum # of observations given by min_obs, and then
+                       weights the observations based on the variance
+                       accordingly. This is the default.
+                    ii. "constant", in which each timestep is averaged over
+                        the same number of observations given by min_obs.
+                    iii. None / False / any other false-like quantity. No
+                       smoothing.
+            min_obs (int): Used with smoothed="max". Minimum number of
+                observations to have before including in the MSD vs dt
+                calculation. E.g. If a structure has 10 diffusing atoms,
+                and min_obs = 30, the MSD vs dt will be
+                calculated up to dt = total_run_time / 3, so that each
+                diffusing atom is measured at least 3 uncorrelated times.
+                Only applies in smoothed="max".
+            avg_nsteps (int): Used with smoothed="constant". Determines the
+                number of time steps to average over to get the msd for each
+                timestep. Default of 1000 is usually pretty good.
+            initial_disp (np.ndarray): Sometimes, you need to iteratively
+                compute estimates of the diffusivity. This supplies an
+                initial displacement that will be added on to the initial
+                displacements. Note that this makes sense only when
+                smoothed=False.
+            initial_structure (Structure): Like initial_disp, this is used
+                for iterative computations of estimates of the diffusivity. You
+                typically need to supply both variables. This stipulates the
+                initial strcture from which the current set of displacements
+                are computed.
         """
         step_skip = vaspruns[0].ionic_step_skip or 1
 
@@ -450,13 +529,15 @@ class DiffusionAnalyzer(PMGSONable):
         temperature = vaspruns[0].parameters['TEEND']
         time_step = vaspruns[0].parameters['POTIM']
 
-        return cls.from_structures(structures, specie, temperature,
-            time_step, step_skip=step_skip, min_obs=min_obs,
-            weighted=weighted)
+        return cls.from_structures(structures=structures, specie=specie,
+            temperature=temperature, time_step=time_step, step_skip=step_skip,
+            smoothed=smoothed, min_obs=min_obs, avg_nsteps=avg_nsteps,
+            initial_disp=initial_disp, initial_structure=initial_structure)
 
     @classmethod
-    def from_files(cls, filepaths, specie, step_skip=10, min_obs=30,
-                   weighted=True, ncores=None):
+    def from_files(cls, filepaths, specie, step_skip=10, smoothed="max",
+                   min_obs=30, avg_nsteps=1000, ncores=None, initial_disp=None,
+                   initial_structure=None):
         """
         Convenient constructor that takes in a list of vasprun.xml paths to
         perform diffusion analysis.
@@ -472,15 +553,27 @@ class DiffusionAnalyzer(PMGSONable):
             step_skip (int): Sampling frequency of the displacements (
                 time_step is multiplied by this number to get the real time
                 between measurements)
-            min_obs (int): Minimum number of observations to have before
-                including in the MSD vs dt calculation. E.g. If a structure
-                has 10 diffusing atoms, and min_obs = 30, the MSD vs dt will be
+            smoothed (str): Whether to smooth the MSD, and what mode to smooth.
+                Supported modes are:
+                    i. "max", which tries to use the maximum #
+                       of data points for each time origin, subject to a
+                       minimum # of observations given by min_obs, and then
+                       weights the observations based on the variance
+                       accordingly. This is the default.
+                    ii. "constant", in which each timestep is averaged over
+                        the same number of observations given by min_obs.
+                    iii. None / False / any other false-like quantity. No
+                       smoothing.
+            min_obs (int): Used with smoothed="max". Minimum number of
+                observations to have before including in the MSD vs dt
+                calculation. E.g. If a structure has 10 diffusing atoms,
+                and min_obs = 30, the MSD vs dt will be
                 calculated up to dt = total_run_time / 3, so that each
                 diffusing atom is measured at least 3 uncorrelated times.
-            weighted (bool): Uses a weighted least squares to fit the
-                MSD vs dt. Weights are proportional to 1/dt, since the
-                number of observations are also proportional to 1/dt (and
-                hence the variance is proportional to dt)
+                Only applies in smoothed="max".
+            avg_nsteps (int): Used with smoothed="constant". Determines the
+                number of time steps to average over to get the msd for each
+                timestep. Default of 1000 is usually pretty good.
             ncores (int): Numbers of cores to use for multiprocessing. Can
                 speed up vasprun parsing considerably. Defaults to None,
                 which means serial. It should be noted that if you want to
@@ -488,11 +581,22 @@ class DiffusionAnalyzer(PMGSONable):
                 .xml files should be a multiple of the ionic_step_skip.
                 Otherwise, inconsistent results may arise. Serial mode has no
                 such restrictions.
+            initial_disp (np.ndarray): Sometimes, you need to iteratively
+                compute estimates of the diffusivity. This supplies an
+                initial displacement that will be added on to the initial
+                displacements. Note that this makes sense only when
+                smoothed=False.
+            initial_structure (Structure): Like initial_disp, this is used
+                for iterative computations of estimates of the diffusivity. You
+                typically need to supply both variables. This stipulates the
+                initial strcture from which the current set of displacements
+                are computed.
         """
-        if ncores is not None:
+        if ncores is not None and len(filepaths) > 1:
             import multiprocessing
             p = multiprocessing.Pool(ncores)
-            vaspruns = p.map(_get_vasprun, [(fp, step_skip) for fp in filepaths])
+            vaspruns = p.map(_get_vasprun,
+                             [(fp, step_skip) for fp in filepaths])
             p.close()
             p.join()
         else:
@@ -504,8 +608,10 @@ class DiffusionAnalyzer(PMGSONable):
                 vaspruns.append(v)
                 # Recompute offset.
                 offset = (- (v.nionic_steps - offset)) % step_skip
-        return cls.from_vaspruns(vaspruns, min_obs=min_obs,
-                                 weighted=weighted, specie=specie)
+        return cls.from_vaspruns(vaspruns, min_obs=min_obs, smoothed=smoothed,
+                                 specie=specie, initial_disp=initial_disp,
+                                 initial_structure=initial_structure,
+                                 avg_nsteps=avg_nsteps)
 
     def as_dict(self):
         return {
@@ -518,7 +624,8 @@ class DiffusionAnalyzer(PMGSONable):
             "time_step": self.time_step,
             "step_skip": self.step_skip,
             "min_obs": self.min_obs,
-            "weighted": self.weighted
+            "smoothed": self.smoothed,
+            "avg_nsteps": self.avg_nsteps
         }
 
     @classmethod
@@ -527,7 +634,8 @@ class DiffusionAnalyzer(PMGSONable):
         return cls(structure, np.array(d["displacements"]), specie=d["specie"],
                    temperature=d["temperature"], time_step=d["time_step"],
                    step_skip=d["step_skip"], min_obs=d["min_obs"],
-                   weighted=d["weighted"], smoothed=d.get("smoothed", True))
+                   smoothed=d.get("smoothed", "max"),
+                   avg_nsteps=d.get("avg_nsteps", 1000))
 
 
 def get_conversion_factor(structure, species, temperature):
