@@ -9,7 +9,7 @@ __author__ = "Shyue Ping Ong"
 __date__ = "Dec 15, 2010 7:21:29 PM"
 
 from .periodic_table import Element, Specie, DummySpecie, get_el_sp
-from .composition import Composition
+from .composition import Composition, ChemicalPotential
 from .structure import Structure, IStructure, Molecule, IMolecule
 from .bonds import CovalentBond, get_bond_length
 from .lattice import Lattice
