@@ -13,13 +13,12 @@ __maintainer__ = "Shyue Ping Ong"
 __email__ = "shyuep@gmail.com"
 __date__ = "May 1, 2012"
 
-
-from collections import OrderedDict
-
-import numpy as np
 import logging
 import math
 import itertools
+from collections import OrderedDict
+
+import numpy as np
 
 from monty.json import jsanitize
 from pymatgen.electronic_structure.core import Spin
@@ -121,8 +120,9 @@ class DosPlotter(object):
         import prettyplotlib as ppl
         from prettyplotlib import brewer2mpl
         from pymatgen.util.plotting_utils import get_publication_quality_plot
-        colors = brewer2mpl.get_map('Set1', 'qualitative',
-                                    len(self._doses)).mpl_colors
+        ncolors = max(3, len(self._doses))
+        ncolors = min(9, ncolors)
+        colors = brewer2mpl.get_map('Set1', 'qualitative', ncolors).mpl_colors
 
         y = None
         alldensities = []
@@ -167,16 +167,16 @@ class DosPlotter(object):
                     y.extend(densities)
             allpts.extend(list(zip(x, y)))
             if self.stack:
-                plt.fill(x, y, color=colors[i],
+                plt.fill(x, y, color=colors[i % ncolors],
                          label=str(key))
             else:
-                ppl.plot(x, y, color=colors[i],
+                ppl.plot(x, y, color=colors[i % ncolors],
                          label=str(key),linewidth=3)
             if not self.zero_at_efermi:
                 ylim = plt.ylim()
                 ppl.plot([self._doses[key]['efermi'],
                           self._doses[key]['efermi']], ylim,
-                          colors[i] + '--', linewidth=2)
+                          colors[i % ncolors] + '--', linewidth=2)
 
         if xlim:
             plt.xlim(xlim)
@@ -404,7 +404,6 @@ class BSPlotter(object):
         plt = get_publication_quality_plot(12, 8)
         from matplotlib import rc
         import scipy.interpolate as scint
-
         rc('text', usetex=True)
 
         #main internal config options
