@@ -71,12 +71,9 @@ class AbinitEvent(yaml.YAMLObject):
         Basic constructor for `AbinitEvent`. 
 
         Args:
-            message:
-                String with human-readable message providing info on the event.
-            src_file:
-                String with the name of the Fortran file where the event is raised.
-            src_line
-                Integer giving the line number in src_file.
+            message: String with human-readable message providing info on the event.
+            src_file: String with the name of the Fortran file where the event is raised.
+            src_line Integer giving the line number in src_file.
         """
         self.message = message
         self._src_file = src_file
@@ -205,10 +202,8 @@ class EventReport(collections.Iterable):
     def __init__(self, filename, events=None):
         """
         Args:
-            filename:
-                Name of the file
-            events:
-                List of Event objects
+            filename: Name of the file
+            events: List of Event objects
         """
         self.filename = os.path.abspath(filename)
         self._events = []
@@ -249,10 +244,7 @@ class EventReport(collections.Iterable):
 
     @property
     def run_completed(self):
-        """
-        Returns True if the calculation terminated.
-        """
-
+        """True if the calculation terminated."""
         try:
             return self._run_completed
         except AttributeError:
@@ -298,8 +290,7 @@ class EventReport(collections.Iterable):
         Return the list of events that inherits from class base_class
 
         Args:
-            only_critical:
-                if True, only critical events are returned.
+            only_critical: if True, only critical events are returned.
         """
         return self._events_by_baseclass[base_class][:]
 
@@ -326,8 +317,7 @@ class EventsParser(object):
 
     def parse(self, filename):
         """
-        This is the new parser, it will be used when we implement
-        the new format in abinit.
+        Parse the given file. Return :class:`EventReport`.
         """
         run_completed = False
         filename = os.path.abspath(filename)
