@@ -4,8 +4,8 @@ from __future__ import unicode_literals, division, print_function
 
 """
 Classes for writing GW Input and analyzing GW data. The underlying classes can handle the use of VASP and ABINIT via the
-code interfaces provided in codeinterfaces.
-Reads the POSCAR_name in the the current folder and outputs GW input to subfolders name or lists of structures
+code interfaces provided in code-interfaces.
+Reads the POSCAR_name in the the current folder and outputs GW input to sub-folders name or lists of structures
 test 3
 """
 
@@ -23,7 +23,6 @@ import ast
 import pymatgen as pmg
 import copy
 import six
-import numpy as np
 
 try:
     import pymongo
@@ -152,7 +151,7 @@ class AbstractAbinitioSpec(MSONable):
 
         if self.data['source'] == 'mp-vasp':
             items_list = mp_list_vasp
-        elif self.data['source'] == 'poscar':
+        elif self.data['source'] in ['poscar', 'cif']:
             files = os.listdir('.')
             items_list = files
         elif self.data['source'] == 'mar_exp':
@@ -162,8 +161,10 @@ class AbstractAbinitioSpec(MSONable):
             pwd = os.environ['MAR_PAS']
             local_db_gaps.authenticate("setten", pwd)
             for c in local_db_gaps.exp.find():
-                print(Structure.from_dict(c['icsd_data']['structure']).composition.reduced_formula, c['icsd_id'],\
-                    c['MP_id'])
+                name = Structure.from_dict(c['icsd_data']['structure']).composition.reduced_formula, c['icsd_id'],\
+                    c['MP_id']
+                print(name)
+                #Structure.from_dict(c['icsd_data']['structure']).to(fmt='cif',filename=name)
                 items_list.append({'name': 'mp-' + c['MP_id'], 'icsd': c['icsd_id'], 'mp': c['MP_id']})
         else:
             items_list = [line.strip() for line in open(self.data['source'])]
@@ -176,6 +177,7 @@ class AbstractAbinitioSpec(MSONable):
                 exp = local_db_gaps.exp.find({'MP_id': item['mp']})[0]
                 structure = Structure.from_dict(exp['icsd_data']['structure'])
                 structure = refine_structure(structure)
+                structure.to(fmt='cif', filename=item['name'])
                 try:
                     kpts = local_db_gaps.GGA_BS.find({'transformations.history.0.id': item['icsd']})[0]['calculations']\
                     [-1]['band_structure']['kpoints']
@@ -409,8 +411,8 @@ class GWSpecs(AbstractAbinitioSpec):
                     if len(data.data) == 0:
                         print('| parm_scr type calculation but no data found.')
                         break
-                    if len(data.data) < 24:
-                        print('| parm_scr type calculation but no complete data found,' \
+                    if len(data.data) < 9:  # todo this should be calculated
+                        print('| parm_scr type calculation but no complete data found,'
                               ' check is all calculations are done.')
                         break
 
@@ -419,8 +421,7 @@ class GWSpecs(AbstractAbinitioSpec):
                         #print data.conv_res
                     else:
                         print('| parm_scr type calculation, no converged scf values found')
-                        data.full_res.update({'remark': 'No converged SCf parameter found. '
-                                                                             'Solution not implemented.'})
+                        data.full_res.update({'remark': 'No converged SCf parameter found. Solution not implemented.'})
                         data.print_full_res()
                         data.conv_res['values'].update({'ecut': 40*eV_to_Ha})
                         data.conv_res['control'].update({'ecut': True})
@@ -428,7 +429,7 @@ class GWSpecs(AbstractAbinitioSpec):
                     # if converged ok, if not increase the grid parameter of the next set of calculations
                     extrapolated = data.find_conv_pars(self['tol'])
                     if data.conv_res['control']['nbands']:
-                        print('| parm_scr type calculation, converged values found, extrapolated value: %s' %\
+                        print('| parm_scr type calculation, converged values found, extrapolated value: %s' %
                               extrapolated[4])
                     else:
                         print('| parm_scr type calculation, no converged values found, increasing grid')
@@ -456,7 +457,7 @@ class GWSpecs(AbstractAbinitioSpec):
                             print(item)
                         done = True
                     if data.test_full_kp_results(tol_rel=1, tol_abs=0.0015):
-                        print('| Full type calculation and the full results agree with the parm_scr.' \
+                        print('| Full type calculation and the full results agree with the parm_scr.'
                               ' All_done for this compound.')
                         data.full_res.update({'all_done': True})
                         data.print_full_res()
@@ -465,7 +466,7 @@ class GWSpecs(AbstractAbinitioSpec):
                         self.code_interface.store_results(name=s_name(structure))
                     else:
                         print('| Full type calculation but the full results do not agree with the parm_scr.')
-                        print('|   Increase the tol to find beter converged parameters and test the full grid again.')
+                        print('|   Increase the tol to find better converged parameters and test the full grid again.')
                         print('|   TODO')
                         # read the system specific tol for System.conv_res
                         # if it's not there create it from the global tol
@@ -847,7 +848,7 @@ class GWConvergenceData():
                        str(self.conv_res['values']['nbands']), ' ', str(self.conv_res['values']['ecuteps']), ' ',
                        str(self.conv_res['values']['gap']), ' "', "' w p\n")
         else:
-            string2 = "%s%s%s" % ("splot '", self.name, ".data' u 1:2:3 w pm3d\n")
+            string2 = "%s%s%s" % ("splot '", self.name, ".data' u 1:2:3 w pm3d\npause -1\n")
         with open(filename, mode='a') as f:
             f.write(string1)
             f.write(string2)
