@@ -8,7 +8,7 @@ Classes for reading/manipulating/writing VASP ouput files.
 
 
 __author__ = "Shyue Ping Ong, Geoffroy Hautier, Rickard Armiento, " + \
-    "Vincent L Chevrier"
+    "Vincent L Chevrier, Ioannis Petousis"
 __credits__ = "Anubhav Jain"
 __copyright__ = "Copyright 2011, The Materials Project"
 __version__ = "1.2"
@@ -245,6 +245,16 @@ class Vasprun(PMGSONable):
         The static part of the dielectric constant. Present when it's a DFPT run
         (LEPSILON=TRUE)
 
+    .. attribute:: epsilon_static_wolfe
+
+        The static part of the dielectric constant without any local field effects.
+        Present when it's a DFPT run (LEPSILON=TRUE)
+
+    .. attribute:: epsilon_ionic
+
+        The ionic part of the static dielectric constant. Present when it's a DFPT run
+        (LEPSILON=TRUE) and IBRION=5, 6, 7 or 8
+
     .. attribute:: nionic_steps
 
         The total number of ionic steps. This number is always equal
@@ -354,7 +364,6 @@ class Vasprun(PMGSONable):
                     self.efermi = self.tdos.efermi
                     self.dos_has_errors = False
                 except Exception as ex:
-                    print(ex)
                     self.dos_has_errors = True
             elif parse_eigen and tag == "eigenvalues":
                 self.eigenvalues = self._parse_eigen(elem)
@@ -377,6 +386,20 @@ class Vasprun(PMGSONable):
         """
         return self.ionic_steps[-1].get("epsilon", [])
 
+    @property
+    def epsilon_static_wolfe(self):
+        """
+        Property only available for DFPT calculations.
+        """
+        return self.ionic_steps[-1].get("epsilon_rpa", [])
+
+    @property
+    def epsilon_ionic(self):
+        """
+        Property only available for DFPT calculations and when IBRION=5, 6, 7 or 8.
+        """
+        return self.ionic_steps[-1].get("epsilon_ion", [])
+
     @property
     def lattice(self):
         return self.final_structure.lattice
@@ -769,6 +792,8 @@ class Vasprun(PMGSONable):
                 vout['projected_eigenvalues'] = peigen
 
         vout['epsilon_static'] = self.epsilon_static
+        vout['epsilon_static_wolfe'] = self.epsilon_static_wolfe
+        vout['epsilon_ionic'] = self.epsilon_ionic
         d['output'] = vout
         return jsanitize(d, strict=True)
 
@@ -834,14 +859,25 @@ class Vasprun(PMGSONable):
         return Structure(latt, self.atomic_symbols, pos)
 
     def _parse_calculation(self, elem):
-        istep = {i.attrib["name"]: float(i.text)
-                 for i in elem.find("energy").findall("i")}
+        try:
+            istep = {i.attrib["name"]: float(i.text)
+                     for i in elem.find("energy").findall("i")}
+        except AttributeError:  # not all calculations have an energy
+            istep = {}
+            pass
         esteps = []
         for scstep in elem.findall("scstep"):
-            d = {i.attrib["name"]: _vasprun_float(i.text)
-                 for i in scstep.find("energy").findall("i")}
-            esteps.append(d)
-        s = self._parse_structure(elem.find("structure"))
+            try:
+                d = {i.attrib["name"]: _vasprun_float(i.text)
+                     for i in scstep.find("energy").findall("i")}
+                esteps.append(d)
+            except AttributeError:  # not all calculations have an energy
+                pass
+        try:
+            s = self._parse_structure(elem.find("structure"))
+        except AttributeError:  # not all calculations have a structure
+            s = None
+            pass
         for va in elem.findall("varray"):
             istep[va.attrib["name"]] = _parse_varray(va)
         istep["electronic_steps"] = esteps
@@ -957,7 +993,6 @@ class Outcar(PMGSONable):
         self.is_stopped = False
 
         # data from end of OUTCAR
-        read_charge_mag = False
         charge = []
         mag = []
         header = []
@@ -974,31 +1009,8 @@ class Outcar(PMGSONable):
         for line in reverse_readfile(self.filename):
             clean = line.strip()
             all_lines.append(clean)
-            if clean.startswith("tot ") and not (charge and mag):
-                read_charge_mag = True
-                data = []
-            elif read_charge_mag:
-                if clean.startswith("# of ion"):
-                    header = re.split("\s{2,}", line.strip())
-                    header.pop(0)
-                elif clean == "total charge":
-                    data.reverse()
-                    charge = [dict(zip(header, v)) for v in data]
-                    read_charge_mag = False
-                elif clean == "magnetization (x)":
-                    data.reverse()
-                    mag = [dict(zip(header, v)) for v in data]
-                    read_charge_mag = False
-                else:
-                    m = re.match("\s*(\d+)\s+(([\d\.\-]+)\s+)+", clean)
-                    if m:
-                        toks = [float(i) for i in re.findall("[\d\.\-]+",
-                                                             clean)]
-                        toks.pop(0)
-                        data.append(toks)
-            elif clean.find("soft stop encountered!  aborting job") != -1:
+            if clean.find("soft stop encountered!  aborting job") != -1:
                 self.is_stopped = True
-                #print(clean, cores)
             else:
                 if time_patt.search(line):
                     tok = line.strip().split(":")
@@ -1023,6 +1035,37 @@ class Outcar(PMGSONable):
                     run_stats]):
                 break
 
+        # For single atom systems, VASP doesn't print a total line, so
+        # reverse parsing is very difficult
+        read_charge = False
+        read_mag = False
+        all_lines.reverse()
+        for clean in all_lines:
+            if read_charge or read_mag:
+                if clean.startswith("# of ion"):
+                    header = re.split("\s{2,}", clean.strip())
+                    header.pop(0)
+                else:
+                    m = re.match("\s*(\d+)\s+(([\d\.\-]+)\s+)+", clean)
+                    if m:
+                        toks = [float(i) for i in re.findall("[\d\.\-]+", clean)]
+                        toks.pop(0)
+                        if read_charge:
+                            charge.append(dict(zip(header, toks)))
+                        else:
+                            mag.append(dict(zip(header, toks)))
+                    elif clean.startswith('tot'):
+                        read_charge = False
+                        read_mag = False
+            if clean == "total charge":
+                charge = []
+                read_charge = True
+                read_mag = False
+            elif clean == "magnetization (x)":
+                mag = []
+                read_mag = True
+                read_charge = False
+
         # data from beginning of OUTCAR
         run_stats['cores'] = 0
         with zopen(filename, "rt") as f:
@@ -1163,33 +1206,38 @@ class Outcar(PMGSONable):
             def dielectric_section_start(results, match):
                 results.dielectric_index = -1
 
-            search.append(["MACROSCOPIC STATIC DIELECTRIC TENSOR", None,
+            search.append(["MACROSCOPIC STATIC DIELECTRIC TENSOR \(", None,
                            dielectric_section_start])
 
             def dielectric_section_start2(results, match):
                 results.dielectric_index = 0
 
-            search.append(["-------------------------------------",
-                           lambda results,
-                           line: results.dielectric_index == -1,
-                           dielectric_section_start2])
+            search.append(
+                ["-------------------------------------",
+                lambda results, line: results.dielectric_index == -1,
+                dielectric_section_start2])
 
             def dielectric_data(results, match):
                 results.dielectric_tensor[results.dielectric_index, :] = \
                     np.array([float(match.group(i)) for i in range(1, 4)])
                 results.dielectric_index += 1
 
-            search.append(["^ *([-0-9.Ee+]+) +([-0-9.Ee+]+) +([-0-9.Ee+]+) *$",
-                           lambda results,
-                           line: results.dielectric_index >= 0,
-                           dielectric_data])
+            search.append(
+                ["^ *([-0-9.Ee+]+) +([-0-9.Ee+]+) +([-0-9.Ee+]+) *$",
+                lambda results, line: results.dielectric_index >= 0
+                                      if results.dielectric_index is not None
+                                      else None,
+                dielectric_data])
 
             def dielectric_section_stop(results, match):
                 results.dielectric_index = None
 
-            search.append(["-------------------------------------",
-                           lambda results, line: results.dielectric_index >= 1,
-                           dielectric_section_stop])
+            search.append(
+                ["-------------------------------------",
+                lambda results, line: results.dielectric_index >= 1
+                                      if results.dielectric_index is not None
+                                      else None,
+                dielectric_section_stop])
 
             self.dielectric_index = None
             self.dielectric_tensor = np.zeros((3, 3))
@@ -1198,7 +1246,7 @@ class Outcar(PMGSONable):
                 results.piezo_index = 0
 
             search.append(["PIEZOELECTRIC TENSOR  for field in x, y, z        "
-                           "\(e  Angst\)",
+                           "\(C/m\^2\)",
                            None, piezo_section_start])
 
             def piezo_data(results, match):
@@ -1206,18 +1254,24 @@ class Outcar(PMGSONable):
                     np.array([float(match.group(i)) for i in range(1, 7)])
                 results.piezo_index += 1
 
-            search.append(["^ *[xyz] +([-0-9.Ee+]+) +([-0-9.Ee+]+)" +
-                           " +([-0-9.Ee+]+) *([-0-9.Ee+]+) +([-0-9.Ee+]+)" +
-                           " +([-0-9.Ee+]+)*$",
-                           lambda results, line: results.piezo_index >= 0,
-                           piezo_data])
+            search.append(
+                ["^ *[xyz] +([-0-9.Ee+]+) +([-0-9.Ee+]+)" +
+                 " +([-0-9.Ee+]+) *([-0-9.Ee+]+) +([-0-9.Ee+]+)" +
+                 " +([-0-9.Ee+]+)*$",
+                 lambda results, line: results.piezo_index >= 0
+                                       if results.piezo_index is not None
+                                       else None,
+                 piezo_data])
 
             def piezo_section_stop(results, match):
                 results.piezo_index = None
 
-            search.append(["-------------------------------------",
-                           lambda results, line: results.piezo_index >= 1,
-                           piezo_section_stop])
+            search.append(
+                ["-------------------------------------",
+                lambda results, line: results.piezo_index >= 1
+                                      if results.piezo_index is not None
+                                      else None,
+                piezo_section_stop])
 
             self.piezo_index = None
             self.piezo_tensor = np.zeros((3, 6))
@@ -1240,26 +1294,123 @@ class Outcar(PMGSONable):
                 results.born[results.born_ion][int(match.group(1)) - 1, :] = \
                     np.array([float(match.group(i)) for i in range(2, 5)])
 
-            search.append(["^ *([1-3]+) +([-0-9.Ee+]+) +([-0-9.Ee+]+) "
-                           "+([-0-9.Ee+]+)$",
-                           lambda results, line: results.born_ion >= 0,
-                           born_data])
+            search.append(
+                ["^ *([1-3]+) +([-0-9.Ee+]+) +([-0-9.Ee+]+) +([-0-9.Ee+]+)$",
+                lambda results, line: results.born_ion >= 0
+                                      if results.born_ion is not None
+                                      else results.born_ion,
+                born_data])
 
             def born_section_stop(results, match):
                 results.born_index = None
 
-            search.append(["-------------------------------------",
-                           lambda results, line: results.born_ion >= 1,
-                           born_section_stop])
+            search.append(
+                ["-------------------------------------",
+                lambda results, line: results.born_ion >= 1
+                                      if results.born_ion is not None
+                                      else results.born_ion,
+                born_section_stop])
 
             self.born_ion = None
             self.born = {}
 
             micro_pyawk(self.filename, search, self)
 
+            self.dielectric_tensor = self.dielectric_tensor.tolist()
+            self.piezo_tensor = self.piezo_tensor.tolist()
+
         except:
             raise Exception("LEPSILON OUTCAR could not be parsed.")
 
+
+    def read_lepsilon_ionic(self):
+        # variables to be filled
+        try:
+            search = []
+
+            def dielectric_section_start(results, match):
+                results.dielectric_ionic_index = -1
+
+            search.append(["MACROSCOPIC STATIC DIELECTRIC TENSOR IONIC", None,
+                           dielectric_section_start])
+
+            def dielectric_section_start2(results, match):
+                results.dielectric_ionic_index = 0
+
+            search.append(
+                ["-------------------------------------",
+                lambda results, line: results.dielectric_ionic_index == -1
+                                      if results.dielectric_ionic_index is not None
+                                      else results.dielectric_ionic_index,
+                dielectric_section_start2])
+
+            def dielectric_data(results, match):
+                results.dielectric_ionic_tensor[results.dielectric_ionic_index, :] = \
+                    np.array([float(match.group(i)) for i in range(1, 4)])
+                results.dielectric_ionic_index += 1
+
+            search.append(
+                ["^ *([-0-9.Ee+]+) +([-0-9.Ee+]+) +([-0-9.Ee+]+) *$",
+                lambda results, line: results.dielectric_ionic_index >= 0
+                                      if results.dielectric_ionic_index is not None
+                                      else results.dielectric_ionic_index,
+                dielectric_data])
+
+            def dielectric_section_stop(results, match):
+                results.dielectric_ionic_index = None
+
+            search.append(
+                ["-------------------------------------",
+                lambda results, line: results.dielectric_ionic_index >= 1
+                                      if results.dielectric_ionic_index is not None
+                                      else results.dielectric_ionic_index,
+                dielectric_section_stop])
+
+            self.dielectric_ionic_index = None
+            self.dielectric_ionic_tensor = np.zeros((3, 3))
+
+            def piezo_section_start(results, match):
+                results.piezo_ionic_index = 0
+
+            search.append(["PIEZOELECTRIC TENSOR IONIC CONTR  for field in x, y, z        ",
+                           None, piezo_section_start])
+
+            def piezo_data(results, match):
+                results.piezo_ionic_tensor[results.piezo_ionic_index, :] = \
+                    np.array([float(match.group(i)) for i in range(1, 7)])
+                results.piezo_ionic_index += 1
+
+            search.append(
+                ["^ *[xyz] +([-0-9.Ee+]+) +([-0-9.Ee+]+)" +
+                 " +([-0-9.Ee+]+) *([-0-9.Ee+]+) +([-0-9.Ee+]+)" +
+                 " +([-0-9.Ee+]+)*$",
+                 lambda results, line: results.piezo_ionic_index >= 0
+                                       if results.piezo_ionic_index is not None
+                                       else results.piezo_ionic_index,
+                 piezo_data])
+
+            def piezo_section_stop(results, match):
+                results.piezo_ionic_index = None
+
+            search.append(
+                ["-------------------------------------",
+                 lambda results, line: results.piezo_ionic_index >= 1
+                                       if results.piezo_ionic_index is not None
+                                       else results.piezo_ionic_index,
+                 piezo_section_stop])
+
+            self.piezo_ionic_index = None
+            self.piezo_ionic_tensor = np.zeros((3, 6))
+
+            micro_pyawk(self.filename, search, self)
+
+            self.dielectric_ionic_tensor = self.dielectric_ionic_tensor.tolist()
+            self.piezo_ionic_tensor = self.piezo_ionic_tensor.tolist()
+
+        except:
+            raise Exception("ionic part of LEPSILON OUTCAR could not be parsed.")
+
+
     def read_lcalcpol(self):
         # variables to be filled
         self.p_elec = None
