@@ -30,10 +30,6 @@ from math import cos
 from math import sin
 
 import numpy as np
-try:
-    import scipy.cluster as spcluster
-except ImportError:
-    spcluster = None
 
 from six.moves import filter, map, zip
 
@@ -45,8 +41,6 @@ from pymatgen.core.operations import SymmOp
 from pymatgen.util.coord_utils import find_in_coord_list
 
 
-from monty.dev import requires
-
 try:
     import pymatgen._spglib as spg
 except ImportError:
@@ -830,8 +824,6 @@ class PointGroupAnalyzer(object):
     """
     inversion_op = SymmOp.inversion()
 
-    @requires(spcluster is not None, "Cannot import scipy. PointGroupAnalyzer "
-                                     "requires scipy.cluster")
     def __init__(self, mol, tolerance=0.3, eigen_tolerance=0.01,
                  matrix_tol=0.1):
         """
@@ -1198,8 +1190,6 @@ class PointGroupAnalyzer(object):
         return True
 
 
-@requires(spcluster is not None, "Cannot import scipy. cluster_sites require "
-                                 "scipy.cluster.")
 def cluster_sites(mol, tol):
     """
     Cluster sites based on distance and species type.
@@ -1216,6 +1206,7 @@ def cluster_sites(mol, tol):
     # Cluster works for dim > 2 data. We just add a dummy 0 for second
     # coordinate.
     dists = [[np.linalg.norm(site.coords), 0] for site in mol]
+    import scipy.cluster as spcluster
     f = spcluster.hierarchy.fclusterdata(dists, tol, criterion='distance')
     clustered_dists = defaultdict(list)
     for i, site in enumerate(mol):
